summaryrefslogtreecommitdiffstats
path: root/chrome/browser/automation/automation_provider.h
diff options
context:
space:
mode:
authornirnimesh@chromium.org <nirnimesh@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-11 06:48:40 +0000
committernirnimesh@chromium.org <nirnimesh@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-11 06:48:40 +0000
commitd1c458a237273c3804131db7fc9a55aa67af48b6 (patch)
treebc65d32671df767b9b28c22e67a6d39a5ec05f4a /chrome/browser/automation/automation_provider.h
parenteb5a99382badcaa174272a2a7c5b3ac11286d6e5 (diff)
downloadchromium_src-d1c458a237273c3804131db7fc9a55aa67af48b6.zip
chromium_src-d1c458a237273c3804131db7fc9a55aa67af48b6.tar.gz
chromium_src-d1c458a237273c3804131db7fc9a55aa67af48b6.tar.bz2
Refactor json automation interface for pyauto hooks.
Reduces the number of lines you need to add per new automation hook. Shaves off several lines of code. Refactor pyauto.py to obviate raising exception in case the json interfaces produces an error string. Review URL: http://codereview.chromium.org/2898001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@52054 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/automation/automation_provider.h')
-rw-r--r--chrome/browser/automation/automation_provider.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/automation/automation_provider.h b/chrome/browser/automation/automation_provider.h
index d8e8d0b..0598179 100644
--- a/chrome/browser/automation/automation_provider.h
+++ b/chrome/browser/automation/automation_provider.h
@@ -463,11 +463,11 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
// data structure used in the browser.
// Args:
// profiles/cards: the ListValue of profiles/credit cards to translate.
// json_return: a pointer to the return string in case of error.
static std::vector<AutoFillProfile> GetAutoFillProfilesFromList(
- const ListValue& profiles, std::string* json_return);
+ const ListValue& profiles, std::string* err_mesg);
static std::vector<CreditCard> GetCreditCardsFromList(
- const ListValue& cards, std::string* json_return);
+ const ListValue& cards, std::string* err_mesg);
// The opposite of the above: translates from the internal data structure
// for profiles and credit cards to a ListValue of DictionaryValues. The
@@ -463,11 +463,11 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
// Args:
// profiles/cards: the ListValue of profiles/credit cards to translate.
- // json_return: a pointer to the return string in case of error.
+ // err_mesg: a pointer to the return string in case of error.
static std::vector<AutoFillProfile> GetAutoFillProfilesFromList(